==> com.liferay.frontend.taglib-5.1.2.jar: META-INF/resources/translation_manager/components/LocaleSelector.js <==
Liferay.Loader.define("frontend-taglib@5.1.2/translation_manager/components/LocaleSelector", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/button', '@frontend-taglib-clay$clayui/drop-down', 'frontend-js-react-web$react'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = LocaleSelector;

  var _button = require("@frontend-taglib-clay$clayui/button");

  var _dropDown = _interopRequireWildcard(require("@frontend-taglib-clay$clayui/drop-down"));

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var DropDownWithState = function DropDownWithState(_ref) {
    var children = _ref.children;

    var _useState = (0, _react.useState)(false),
        _useState2 = _slicedToArray(_useState, 2),
        isDropdownOpen = _useState2[0],
        setIsDropdownOpen = _useState2[1];

    return _react["default"].createElement(_dropDown["default"], {
      active: isDropdownOpen,
      alignmentPosition: _dropDown.Align.BottomCenter,
      onActiveChange: function onActiveChange(isActive) {
        return setIsDropdownOpen(isActive);
      },
      trigger: _react["default"].createElement(_button.ClayButtonWithIcon, {
        borderless: true,
        displayType: "secondary",
        small: true,
        symbol: "plus"
      })
    }, children);
  };

  function LocaleSelector(_ref2) {
    var locales = _ref2.locales,
        onItemClick = _ref2.onItemClick;
    return _react["default"].createElement(DropDownWithState, null, _react["default"].createElement(_dropDown["default"].ItemList, null, locales.map(function (locale) {
      return _react["default"].createElement(_dropDown["default"].Item, {
        id: locale.id,
        key: locale.id,
        onClick: function onClick() {
          return onItemClick && onItemClick(locale);
        },
        symbolRight: locale.icon
      }, locale.label);
    })));
  }
  //# sourceMappingURL=LocaleSelector.js.map
});
//# sourceMappingURL=LocaleSelector.js.map

==> com.liferay.frontend.taglib-5.4.3.jar: META-INF/resources/translation_manager/components/LocaleSelector.js <==
Liferay.Loader.define("frontend-taglib@5.4.3/translation_manager/components/LocaleSelector", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/button', '@frontend-taglib-clay$clayui/drop-down', 'frontend-js-react-web$react'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = LocaleSelector;

  var _button = require("@frontend-taglib-clay$clayui/button");

  var _dropDown = _interopRequireWildcard(require("@frontend-taglib-clay$clayui/drop-down"));

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var DropDownWithState = function DropDownWithState(_ref) {
    var children = _ref.children;

    var _useState = (0, _react.useState)(false),
        _useState2 = _slicedToArray(_useState, 2),
        isDropdownOpen = _useState2[0],
        setIsDropdownOpen = _useState2[1];

    return _react["default"].createElement(_dropDown["default"], {
      active: isDropdownOpen,
      alignmentPosition: _dropDown.Align.BottomCenter,
      onActiveChange: function onActiveChange(isActive) {
        return setIsDropdownOpen(isActive);
      },
      trigger: _react["default"].createElement(_button.ClayButtonWithIcon, {
        borderless: true,
        displayType: "secondary",
        small: true,
        symbol: "plus"
      })
    }, children({
      setActive: setIsDropdownOpen
    }));
  };

  function LocaleSelector(_ref2) {
    var locales = _ref2.locales,
        onItemClick = _ref2.onItemClick;
    return _react["default"].createElement(DropDownWithState, null, function (_ref3) {
      var setActive = _ref3.setActive;
      return _react["default"].createElement(_dropDown["default"].ItemList, null, locales.map(function (locale) {
        return _react["default"].createElement(_dropDown["default"].Item, {
          id: locale.id,
          key: locale.id,
          onClick: function onClick() {
            onItemClick(locale);
            setActive(false);
          },
          symbolRight: locale.icon
        }, locale.label);
      }));
    });
  }
  //# sourceMappingURL=LocaleSelector.js.map
});
//# sourceMappingURL=LocaleSelector.js.map
